@@ -4,7 +4,7 @@ use 5.008_001;
 use strict;
 use warnings;
 
-our $VERSION = '3.3.3';
+our $VERSION = '3.3.4';
 
 use Carp              ();
 use File::Spec        ();
@@ -33,6 +33,8 @@ my $BYTECODE_VERSION = '1.6';
 # $bytecode_version + $fullpath + $compiler_and_parser_options
 my $XSLATE_MAGIC   = qq{xslate;$BYTECODE_VERSION;%s;%s;};
 
+our $DEFAULT_CACHE_DIR;
+
 # load backend (XS or PP)
 my $use_xs = 0;
 if(!exists $INC{'Text/Xslate/PP.pm'}) {
@@ -72,7 +74,9 @@ BEGIN {
     *_SAVE_SRC  = sub() { $save_src };
 
     *_ST_MTIME = sub() { 9 }; # see perldoc -f stat
+}
 
+unless(defined $DEFAULT_CACHE_DIR) {
     my $cache_dir = '.xslate_cache';
     foreach my $d($ENV{HOME}, File::Spec->tmpdir) {
         if(defined($d) and -d $d and -w _) {
@@ -80,7 +84,8 @@ BEGIN {
             last;
         }
     }
-    *_DEFAULT_CACHE_DIR = sub() { $cache_dir };
+
+    $DEFAULT_CACHE_DIR = $cache_dir;
 }
 
 # the real defaults are defined in the parser
@@ -140,7 +145,7 @@ sub options { # overridable
         path         => ['.'],
         input_layer  => $self->input_layer,
         cache        => 1, # 0: not cached, 1: checks mtime, 2: always cached
-        cache_dir    => _DEFAULT_CACHE_DIR,
+        cache_dir    => $DEFAULT_CACHE_DIR,
         module       => undef,
         function     => undef,
         html_builder_module => undef,
@@ -663,7 +668,7 @@ Text::Xslate - Scalable template engine for Perl5
 
 =head1 VERSION
 
-This document describes Text::Xslate version 3.3.3.
+This document describes Text::Xslate version 3.3.4.
 
 =head1 SYNOPSIS
 
@@ -769,8 +774,8 @@ engine and even add a new syntax via extending the parser.
 
 =head3 B<< Text::Xslate->new(%options) >>
 
-Creates a new Xslate template engine with options. You can reuse the instance
-for multiple call of C<render()>.
+Creates a new Xslate template engine with options. You can reuse this instance
+for multiple calls to C<render()>.
 
 Possible options are:
 
@@ -810,13 +815,13 @@ template names.
 Specifies a function map which contains name-coderef pairs.
 A function C<f> may be called as C<f($arg)> or C<$arg | f> in templates.
 
-Note that those registered function have to return a B<text string>,
+Note that these registered functions have to return a B<text string>,
 not a binary string unless you want to handle bytes in whole templates.
-Make sure what you want to use returns whether text string or binary
-strings.
+Make sure what you want to use returns either a text string or a binary
+string.
 
 For example, some methods of C<Time::Piece> might return a binary string
-which is encoded in UTF-8, so you'd like to decode their values.
+which is encoded in UTF-8, so you'll want to decode their values.
 
     # under LANG=ja_JP.UTF-8 on MacOSX (Darwin 11.2.0)
     use Time::Piece;
@@ -1064,11 +1069,11 @@ This function is available in templates as the C<unmark_raw> filter.
 Escapes HTML meta characters in I<$str>, and returns it as a raw string (see above).
 If I<$str> is already a raw string, it returns I<$str> as is.
 
-By default, this function will be automatically applied to all the template
+By default, this function will automatically be applied to all template
 expressions.
 
-This function is available in templates as the C<html> filter, but you'd better
-to use C<unmark_raw> to ensure expressions to be html-escaped.
+This function is available in templates as the C<html> filter, but you're better
+off using C<unmark_raw> to ensure that expressions are html-escaped.
 
 =head3 C<< uri_escape($str :Str) :Str >>
 
@@ -1226,20 +1231,13 @@ A "too-safe" HTML escaping filter which escape all the symbolic characters
 
 WEB: L<http://xslate.org/>
 
-ML: L<http://groups.google.com/group/xslate>
-
-IRC: #xslate @ irc.perl.org
-
 PROJECT HOME: L<http://github.com/xslate/>
 
 REPOSITORY: L<http://github.com/xslate/p5-Text-Xslate/>
 
 =head1 BUGS
 
-All complex software has bugs lurking in it, and this module is no
-exception. If you find a bug please either email me, or add the bug
-to cpan-RT. Patches are welcome :)
-
+Please make a file on L<http://github.com/xslate/>. Patches are always welcome.
 =head1 SEE ALSO
 
 Documents:
