@@ -78,8 +78,8 @@ Hash:
 
     : foo({ foo => "bar" })
 
-Note that C<{ ... }> is always parsed as hash literals, so you need not
-to use prefix:<+> as Perl sometimes requires:
+Note that C<{ ... }> is always parsed as hash literals, so you don't need
+to use the <+> prefix as Perl sometimes requires:
 
     :  {}.kv(); # ok
     : +{}.kv(); # also ok
@@ -153,7 +153,7 @@ These two statements has the same semantics, so you cannot modify C<$foo>.
 
 =head2 Loops
 
-There is C<for> loops that are like Perl's C<foreach>.
+There are C<for> loops that are like Perl's C<foreach>.
 
     : # iterate over an ARRAY reference
     : for $data -> $item {
@@ -166,7 +166,7 @@ There is C<for> loops that are like Perl's C<foreach>.
         <: $key :>=<: $data[$key] :>
     : }
 
-And the C<for> statement can take C<else> block:
+And the C<for> statement can take an C<else> block:
 
     : for $data -> $item {
         [<: $item.field :>]
@@ -349,6 +349,14 @@ Template inclusion is a traditional way to extend templates.
     : include "foo.tx" { var1 => value1, var2 => value2, ... };
     : include "foo.tx" {$vars}; # use $vars as the params
 
+if a var exist in the {$vars} and __ROOT__, the one in {$vars} will win.
+
+also, be careful about the order of vars. 
+
+    : include "foo.tx" { var1 => $id, id => $var, var2 => $id }
+
+var1 and var2 will be replaced by $id, var2 will be replaced by $var, because the value of id is changed
+
 As C<cascade> does, C<include> allows barewords:
 
     : include foo      # the same as 'foo.tx'
@@ -481,18 +489,18 @@ because template cascading is statically processed.
 =head2 Macro blocks
 
 Macros are supported, which are called in the same way as functions and
-return a C<raw> string. Macros returns what their bodies render, so
-they cannot return references nor objects including other macros.
+return a C<raw> string. Macros return what their bodies render, so
+they cannot return references or objects, including other macros.
 
     : macro add ->($x, $y) {
     :   $x + $y;
     : }
     : add(10, 20)
 
-    : macro signeture -> {
+    : macro signature -> {
         This is foo version <: $VERSION :>
     : }
-    : signeture()
+    : signature()
 
     : macro factorial -> $x {
     :   $x == 0 ? 1 : $x * factorial($x-1)
